@@ -109,7 +109,7 @@ class MinioAgent(ABC):
     def filter_objects_todo(
         self, object_names: List[str], bucket_name: str
     ) -> List[str]:
-        return [name for name in object_names if not self.is_already_processed(object_name=name, bucket_name)]
+        return [name for name in object_names if not self.is_already_processed(object_name=name, bucket_name=bucket_name)]
 
     def tag_objects_as_processed(
         self, object_names_processed: List[str], bucket_name: str
